@@ -1,4 +1,4 @@
-from enum import Enum#
+from enum import Enum
 
 
 class SALUSInformation:
@@ -12,7 +12,7 @@ class SALUSInformation:
 
     @property
     def gateway(self):
-        return next(filter(lambda x: not x["data"]["DeviceType"] == 300, self._raw_information))
+        return next(filter(lambda x: x["data"]["DeviceType"] == 200, self._raw_information))
 
     @property
     def version(self):
